Documentation
¶
Overview ¶
Package peeradmission answers inbound hello requests: it classifies the calling peer by probing it back, and returns a bounded freshest set of reachable peers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MountHello ¶
func MountHello( router httpguard.WireRouter, identity nodeidentity.Identity, exchange HelloExchange, )
Types ¶
type HelloExchange ¶
type HelloExchange struct {
Status RuntimeStatus
Reachability ReachableRoster
Client *http.Client
News NewsIntake
PreferHTTPS bool
NetworkAccess yagoproto.NetworkAccess
}
type NewsIntake ¶
type ReachableRoster ¶
Click to show internal directories.
Click to hide internal directories.